import Flutter
import UIKit

public class SwiftAdfurikunPlugin: NSObject, FlutterPlugin {
    private let channel: FlutterMethodChannel
    private let fullscreenAdManager: FullscreenAdManager
    private let infeedAdManager: InfeedAdManager
    
    init(_ channel: FlutterMethodChannel, _ register: FlutterPluginRegistrar) {
        self.channel = channel
        fullscreenAdManager = FullscreenAdManager(channel)
        infeedAdManager = InfeedAdManager(channel, register)
    }
    
    public static func register(with registrar: FlutterPluginRegistrar) {
        let channel = FlutterMethodChannel(name: ADFConst.ADFURIKUN_METHOD_CHANNEL, binaryMessenger: registrar.messenger())
        let instance = SwiftAdfurikunPlugin(channel, registrar)
        registrar.addMethodCallDelegate(instance, channel: channel)
    }
    
    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        if checkAdType(call, adTypeString: ADFConst.AD_TYPE_REWARD) {
            fullscreenAdManager.handle(call, result, ADFConst.AD_TYPE_REWARD)
        } else if checkAdType(call, adTypeString: ADFConst.AD_TYPE_INTERSTITIAL) {
            fullscreenAdManager.handle(call, result, ADFConst.AD_TYPE_INTERSTITIAL)
        } else if checkAdType(call, adTypeString: ADFConst.AD_TYPE_NATIVEAD) {
            infeedAdManager.handle(call, result, ADFConst.AD_TYPE_NATIVEAD)
        } else if checkAdType(call, adTypeString: ADFConst.AD_TYPE_RECTANGLE) {
            infeedAdManager.handle(call, result, ADFConst.AD_TYPE_RECTANGLE)
        } else if checkAdType(call, adTypeString: ADFConst.AD_TYPE_BANNER) {
            infeedAdManager.handle(call, result, ADFConst.AD_TYPE_BANNER)
        } else {
            OptionsManager.handle(call, result)
        }
    }
    
    private func checkAdType(_ call: FlutterMethodCall, adTypeString: String) -> Bool {
        return call.method.hasSuffix(ADFConst.SEPARATOR_METHOD + adTypeString)
    }
}
