import 'dart:io';
import 'package:flutter/widgets.dart';
import 'package:flutter/services.dart';
import 'package:flutter/material.dart';
import 'constants.dart';
import 'ad_base.dart';
import 'adfurikun_plugin.dart';

enum AdfurikunBannerCallback {
  onBannerLoadFinish,
  onBannerLoadError,
  onBannerViewPlayStart,
  onBannerViewPlayFinish,
  onBannerViewPlayFail,
  onBannerViewClicked
}

typedef AdfurikunBannerListener(
    AdfurikunBannerCallback? callback,
    String? appId,
    String? adNetworkKey,
    String? title,
    String? description,
    int? errorCode);

class AdfurikunBanner extends AdfurikunAdBase {
  final double width;
  final double height;
  AdfurikunBannerListener? listener;

  late final AdfurikunWidget _view;

  Map<String, AdfurikunBannerCallback> _callbackMap = {
    CALLBACK_ON_BANNER_LOAD_FINISH: AdfurikunBannerCallback.onBannerLoadFinish,
    CALLBACK_ON_BANNER_LOAD_ERROR: AdfurikunBannerCallback.onBannerLoadError,
    CALLBACK_ON_BANNER_VIEW_PLAY_START: AdfurikunBannerCallback.onBannerViewPlayStart,
    CALLBACK_ON_BANNER_VIEW_PLAY_FINISH: AdfurikunBannerCallback.onBannerViewPlayFinish,
    CALLBACK_ON_BANNER_VIEW_PLAY_FAIL: AdfurikunBannerCallback.onBannerViewPlayFail,
    CALLBACK_ON_BANNER_VIEW_CLICKED: AdfurikunBannerCallback.onBannerViewClicked
  };

  AdfurikunBanner(String appId, this.width, this.height) : super(appId, AD_TYPE_BANNER) {
    _view = AdfurikunWidget(number, appId, adType, width, height);
    AdfurikunPlugin.invoke(method(METHOD_INIT), argsWithSize(width, height));
  }

  StatefulWidget adWidget() {
    return _view;
  }

  void load() {
    AdfurikunPlugin.invoke(method(METHOD_LOAD), args());
  }

  void loadWithTimeout(int timeout) {
    Map<String, Object> map = args();
    map[KEY_TIMEOUT] = timeout;
    AdfurikunPlugin.invoke(method(METHOD_LOAD), map);
  }

  void play() {
    AdfurikunPlugin.invoke(method(METHOD_PLAY), args());
  }

  @override
  void destroy() {
    super.destroy();
    AdfurikunPlugin.invoke(method(METHOD_DESTROY), args());
  }

  @override
  void notifyListener(MethodCall call) {
    if (listener != null) {
      AdfurikunBannerCallback? callback = _callbackMap[call.method];
      String? appId = call.arguments[KEY_APP_ID];
      String? adNetworkKey = call.arguments[KEY_AD_NETWORK_KEY];
      String? title = call.arguments[KEY_TITLE];
      String? description = call.arguments[KEY_DESCRIPTION];
      int? errorCode = call.arguments[KEY_ERROR_CODE];
      listener!(callback, appId, adNetworkKey, title, description, errorCode);
    } else {
      print('AdfurikunBannerListener is null');
    }
  }
}