import 'dart:io';
import 'package:flutter/widgets.dart';
import 'package:flutter/services.dart';
import 'package:flutter/material.dart';
import 'constants.dart';
import 'ad_base.dart';
import 'adfurikun_plugin.dart';

enum AdfurikunNativeAdCallback {
  onNativeAdLoadFinish,
  onNativeAdLoadError,
  onNativeAdViewPlayStart,
  onNativeAdViewPlayFinish,
  onNativeAdViewPlayFail,
  onNativeAdViewClicked
}

typedef AdfurikunNativeAdListener(
    AdfurikunNativeAdCallback? callback,
    String? appId,
    String? adNetworkKey,
    String? title,
    String? description,
    int? errorCode);

class AdfurikunNativeAd extends AdfurikunAdBase {
  final double width;
  final double height;
  AdfurikunNativeAdListener? listener;

  late final AdfurikunWidget _view;

  Map<String, AdfurikunNativeAdCallback> _callbackMap = {
    CALLBACK_ON_NATIVEAD_LOAD_FINISH: AdfurikunNativeAdCallback.onNativeAdLoadFinish,
    CALLBACK_ON_NATIVEAD_LOAD_ERROR: AdfurikunNativeAdCallback.onNativeAdLoadError,
    CALLBACK_ON_NATIVEAD_VIEW_PLAY_START: AdfurikunNativeAdCallback.onNativeAdViewPlayStart,
    CALLBACK_ON_NATIVEAD_VIEW_PLAY_FINISH: AdfurikunNativeAdCallback.onNativeAdViewPlayFinish,
    CALLBACK_ON_NATIVEAD_VIEW_PLAY_FAIL: AdfurikunNativeAdCallback.onNativeAdViewPlayFail,
    CALLBACK_ON_NATIVEAD_VIEW_CLICKED: AdfurikunNativeAdCallback.onNativeAdViewClicked
  };

  AdfurikunNativeAd(String appId, this.width, this.height) : super(appId, AD_TYPE_NATIVEAD) {
    _view = AdfurikunWidget(number, appId, adType, width, height);
    AdfurikunPlugin.invoke(method(METHOD_INIT), argsWithSize(width, height));
  }

  StatefulWidget adWidget() {
    return _view;
  }

  void load() {
    AdfurikunPlugin.invoke(method(METHOD_LOAD), args());
  }

  void loadWithTimeout(int timeout) {
    Map<String, Object> map = args();
    map[KEY_TIMEOUT] = timeout;
    AdfurikunPlugin.invoke(method(METHOD_LOAD), map);
  }

  void play() {
    AdfurikunPlugin.invoke(method(METHOD_PLAY), args());
  }

  @override
  void destroy() {
    super.destroy();
    AdfurikunPlugin.invoke(method(METHOD_DESTROY), args());
  }

  @override
  void notifyListener(MethodCall call) {
    if (listener != null) {
      AdfurikunNativeAdCallback? callback = _callbackMap[call.method];
      String? appId = call.arguments[KEY_APP_ID];
      String? adNetworkKey = call.arguments[KEY_AD_NETWORK_KEY];
      String? title = call.arguments[KEY_TITLE];
      String? description = call.arguments[KEY_DESCRIPTION];
      int? errorCode = call.arguments[KEY_ERROR_CODE];
      listener!(callback, appId, adNetworkKey, title, description, errorCode);
    } else {
      print('AdfurikunNativeAdListener is null');
    }
  }
}